Structs
- Aligned
Vec - A vector of bytes that aligns its memory to the specified alignment.
- Bincode
Codec - A codec that relies on
bincodeto encode data. - Bincode
Serde Codec - A codec that relies on
bincodeandserdeto encode data in the bincode format. - Bitcode
Codec - A codec that relies on
bitcodeto encode data. - Bitcode
Serde Codec - A codec that relies on
bitcodeandserdeto encode data in the bitcode format. - From
ToBytes Codec - A binary codec that uses rust own binary encoding functions to encode and decode data.
This can be used if you want to encode only primitives and don’t want to rely on third party
crates like
bincodeorrmp-serde. If you have more complex data check out [BincodeSerdeCodec] or [MsgpackSerdeCodec]. - Msgpack
Serde Codec - A codec that relies on
rmp-serdeto encode data in the msgpack format. - Postcard
Codec - A codec that relies on
postcardto encode data. - Prost
Codec - A codec for storing ProtoBuf messages that relies on
prostto parse. - Rkyv
Codec - A codec that relies on
rkyvto encode data in the msgpack format.