Module binary

Module binary 

Structs

AlignedVec
A vector of bytes that aligns its memory to the specified alignment.
BincodeCodec
A codec that relies on bincode to encode data.
BincodeSerdeCodec
A codec that relies on bincode and serde to encode data in the bincode format.
FromToBytesCodec
A binary codec that uses rust own binary encoding functions to encode and decode data. This can be used if you want to encode only primitives and don’t want to rely on third party crates like bincode or rmp-serde. If you have more complex data check out [BincodeSerdeCodec] or [MsgpackSerdeCodec].
MsgpackSerdeCodec
A codec that relies on rmp-serde to encode data in the msgpack format.
ProstCodec
A codec for storing ProtoBuf messages that relies on prost to parse.
RkyvCodec
A codec that relies on rkyv to encode data in the msgpack format.

Enums

FromToBytesCodecError